@@ -117,7 +117,8 @@ class _Compiler(object):
             return self._compile_pi(node)
         elif node.tagName.startswith('py:'):
             # Handle directives
-            compiler = getattr(self, '_compile_%s' % node.tagName.split(':')[-1])
+            compiler = getattr(self, '_compile_%s' % node.tagName.split(':')[-1],
+                               self._compile_xml)
             return compiler(node)
         else:
             return self._compile_xml(node)
@@ -130,7 +131,8 @@ class _Compiler(object):
             node.removeAttribute('py:strip')
         yield ir.TextNode(u'<%s' % node.tagName, guard)
         for k,v in node.attributes.items():
-            tc = _TextCompiler(self.filename, v, node.lineno)
+            tc = _TextCompiler(self.filename, v, node.lineno,
+                               ir.TextNode)
             v = list(tc)
             # v = u''.join(n.text for n in tc)
             if k == 'py:content':
@@ -156,9 +158,11 @@ class _Compiler(object):
                         and node.tagName in HTML_OPTIONAL_END_TAGS):
                     yield ir.TextNode(u'</%s>' % node.tagName, guard)
             else:
-                if (self.mode.startswith('html')
-                    and node.tagName in HTML_OPTIONAL_END_TAGS):
-                    yield ir.TextNode(u'>', guard)
+                if self.mode.startswith('html'):
+                    if  node.tagName in HTML_OPTIONAL_END_TAGS:
+                        yield ir.TextNode(u'>', guard)
+                    else:
+                        yield ir.TextNode(u'></%s>' % node.tagName, guard)
                 else:
                     yield ir.TextNode(u'/>', guard)
 
@@ -277,15 +281,17 @@ class _Compiler(object):
 
 class _TextCompiler(object):
 
-    def __init__(self, filename, source, lineno):
+    def __init__(self, filename, source, lineno,
+                 node_type=ir.TranslatableTextNode):
         self.filename = filename
         self.source = source
         self.orig_lineno = lineno
         self.lineno = 0
         self.pos = 0
+        self.node_type = node_type
         
     def text(self, text):
-        node = ir.TextNode(text)
+        node = self.node_type(text)
         node.lineno = self.real_lineno
         self.lineno += text.count('\n')
         return node
